==> ejc-credentials-impl-3.0.0-20220608.033454-41-sources.jar: com/ejianc/certify/bean/LendresBEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 公司借证归还-表体
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corplendres_b")
public class LendresBEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="crowno")
    private Integer crowno; // 行号
    @TableField(value="isgh")
    private String isgh; // 是否归还
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_corplendres")
    private Long pkCorplendres; // 主表主键
    @TableField(value="pk_corpcertify_f")
    private Long pkCorpcertifyF; // 证件配件详情主键
    @TableField(value="pk_certifreg")
    private Long pkCertifreg;
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 证书类别
    @TableField(value="pk_certpsn")
    private Long pkCertpsn; // 证书人员
    @TableField(value="certifcode")
    private String certifcode; // 证书编号
    @TableField(value="jydate")
    private String jydate; // 配证日期
    @TableField(value="isjyyj")
    private String isjyyj; // 原件/扫描件
    @TableField(value="yjjc_date")
    private String yjjcDate; // 原件借出日期
    @TableField(value="isyyz")
    private String isyyz; // 是否已押证
    @TableField(value="isbjsuccess")
    private String isbjsuccess; // 是否报建成功
    @TableField(value="sjgh_date")
    private String sjghDate; // 实际归还日期
    @TableField(value="isyjgh")
    private String isyjgh; // 是否已归还
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 

    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorplendres() {
        return pkCorplendres;
    }

    public void setPkCorplendres(Long pkCorplendres) {
        this.pkCorplendres = pkCorplendres;
    }
    public Long getPkCorpcertifyF() {
        return pkCorpcertifyF;
    }

    public void setPkCorpcertifyF(Long pkCorpcertifyF) {
        this.pkCorpcertifyF = pkCorpcertifyF;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }
    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }
    public String getSjghDate() {
        return sjghDate;
    }

    public void setSjghDate(String sjghDate) {
        this.sjghDate = sjghDate;
    }
    public String getIsyjgh() {
        return isyjgh;
    }

    public void setIsyjgh(String isyjgh) {
        this.isyjgh = isyjgh;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220616.071707-59-sources.jar: com/ejianc/certify/bean/LendresBEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 公司借证归还-表体
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corplendres_b")
public class LendresBEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="crowno")
    private Integer crowno; // 行号
    @TableField(value="isgh")
    private String isgh; // 是否归还
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_corplendres")
    private Long pkCorplendres; // 主表主键
    @TableField(value="pk_corpcertify_f")
    private Long pkCorpcertifyF; // 证件配件详情主键
    @TableField(value="pk_certifreg")
    private Long pkCertifreg;
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 证书类别
    @TableField(value="pk_certpsn")
    private Long pkCertpsn; // 证书人员
    @TableField(value="certifcode")
    private String certifcode; // 证书编号
    @TableField(value="jydate")
    private String jydate; // 配证日期
    @TableField(value="isjyyj")
    private String isjyyj; // 原件/扫描件
    @TableField(value="yjjc_date")
    private String yjjcDate; // 原件借出日期
    @TableField(value="isyyz")
    private String isyyz; // 是否已押证
    @TableField(value="isbjsuccess")
    private String isbjsuccess; // 是否报建成功
    @TableField(value="sjgh_date")
    private String sjghDate; // 实际归还日期
    @TableField(value="isyjgh")
    private String isyjgh; // 是否已归还
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; //
    @TableField(value="pk_corpcertify")
    private String pkCorpcertify;

    public String getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(String pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }

    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorplendres() {
        return pkCorplendres;
    }

    public void setPkCorplendres(Long pkCorplendres) {
        this.pkCorplendres = pkCorplendres;
    }
    public Long getPkCorpcertifyF() {
        return pkCorpcertifyF;
    }

    public void setPkCorpcertifyF(Long pkCorpcertifyF) {
        this.pkCorpcertifyF = pkCorpcertifyF;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }
    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }
    public String getSjghDate() {
        return sjghDate;
    }

    public void setSjghDate(String sjghDate) {
        this.sjghDate = sjghDate;
    }
    public String getIsyjgh() {
        return isyjgh;
    }

    public void setIsyjgh(String isyjgh) {
        this.isyjgh = isyjgh;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
